@@ -1,18 +1,19 @@
 package Gtk2::GladeXML::OO;
 
-use vars qw($VERSION @ISA @EXPORT $LOG $tmp);
+use vars qw($VERSION $LOG $tmp);
 use strict;
 use warnings;
-require Exporter;
+use base 'Gtk2::GladeXML';
+use Hook::LexWrap qw(wrap);
 #======================================================================
-$VERSION = '0.034';
-@ISA = qw(Exporter);
-@EXPORT = qw(_autoload_gtk);
+$VERSION = '0.361';
 #======================================================================
 use constant TRUE => not undef;
 use constant FALSE => undef;
 #======================================================================
-my ($widget, $objects);
+my ($gladexml, $widget, $objects, $LOG);
+#======================================================================
+wrap Gtk2::GladeXML::new, post => sub { $gladexml = $_[-1]; };
 #======================================================================
 sub _log {
 	my ($object, $method, @params) = @_;
@@ -35,10 +36,10 @@ EOF
 
 }
 #======================================================================
-sub _autoload_gtk {
-	my ($gladexml, $str) = (shift, shift);
-	 
-	my ($object, $method, $params) = $str =~ /^main::(.+)->([^\(]+)(.*)/;
+sub Gtk2::GladeXML::debug { $LOG = $_[1]; }
+#======================================================================
+sub main::AUTOLOAD {
+	my ($object, $method, $params) = $main::AUTOLOAD =~ /^main::(.+)->([^\(]+)(.*)/;
 
 	my @params;
 	if($params){
@@ -70,24 +71,23 @@ sub _autoload_gtk {
 	warn qq/Unknown method "$method" of object "$object"!\n/ and return unless $objects->{$object}->can($method);
 	$objects->{$object}->$method(@params);
 	return TRUE;
-}
+};
 #======================================================================
 1;
 
 =head1 NAME
 
-Gtk2::GladeXML::OO - Object oriented interface to Glade.
+Gtk2::GladeXML::OO - Drop-in replacement for Gtk2::GladeXML with object oriented interface to Glade and AUTOLOAD for all objects.
 
 
 =head1 SYNOPSIS
 
-	use Gtk2::GladeXML;
 	use Gtk2::GladeXML::OO;
 	
-	our $gladexml = Gtk2::GladeXML->new('glade/example.glade');
+	our $gladexml = Gtk2::GladeXML::OO->new('glade/example.glade');
 	$gladexml->signal_autoconnect_from_package('main');
 
-	sub AUTOLOAD { _autoload_gtk($gladexml, our $AUTOLOAD, @_); }
+	$gladexml->debug(1);
 
 	sub gtk_main_quit { Gtk2->main_quit; }
 
@@ -109,23 +109,33 @@ Gtk2::GladeXML::OO - Object oriented interface to Glade.
 
 =head1 DESCRIPTION
 
-This module provides object oriented interface in Glade callbacks. Now You can use in callbacks widget, Your objects or standard functions like before.
+This module provides AUTOLOAD function for objects (automagicaly loads Your objects, B<no action is required on your part>) and object-oriented interface in Glade callbacks. Now You can use in callbacks: widgets, Your objects or standard functions like before.
+Gtk2::GladeXML::OO is a drop-in replacement for Gtk2::GladeXML, so after change from Gtk2::GladeXML to Gtk2::GladeXML::OO all Your applications will work fine and will have new functionality.
 
 =head1 SUBROUTINES/METHODS
 
 =over 4
 
-=item B<_autoload_gtk($gladexml, our $AUTOLOAD, @_)>
+=item B<new('/path/to/file.glade')>
 
-This method should be called with 3 parameters somewhere in AUTOLOAD sub in main package. In example:
+This method should be called exactly as C<new> in Gtk2::GladeXML. In example:
 
-	sub AUTOLOAD { _autoload_gtk($gladexml, our $AUTOLOAD, @_); }
+	# Gtk2::GladeXML::OO object
+	our $gladexml = Gtk2::GladeXML::OO->new('glade/example.glade');
 
-	# $galdexml - GladeXML object
+=item B<debug>
 
-=item B<$Gtk2::GladeXML::OO::LOG>
+This method turns on/off debug. In example:
+	
+	# tunrs ON debug
+	$gladexml->debug(1);
+	
+	...some code...
 
-Set this variable to true for debug.
+	# turns OFF debug
+	$gledexml->debug(0);
+
+=item B<For all other methods see C<Gtk2::GladeXML>!>
 
 =back
 
@@ -133,16 +143,16 @@ Set this variable to true for debug.
 
 =over 4
 
-=item Gtk2::GladeXML
+=item Hook::LexWrap
 
-=item Exporter
+=item Gtk2::GladeXML
 
 =back
 
 
 =head1 INCOMPATIBILITIES
 
-None known.
+This package will define C<AUTOLOAD> function in C<main> package. You should consider this (little work around?), when You're using AUTOLOAD in Your application (exactly main::AUTOLOAD). This will be corrected in future versions.
 
 =head1 BUGS AND LIMITATIONS
 
